.. currentmodule:: iniabu.utilities

=============================
Utility classes and functions
=============================

:class:`ProxyList`
------------------

.. autoclass:: ProxyList
    :members:
    :undoc-members:


:func:`get_all_available_isos`
------------------------------

.. autofunction:: get_all_available_isos

:func:`get_all_stable_isos`
---------------------------

.. autofunction:: get_all_stable_isos

:func:`item_formatter`
-----------------------

.. autofunction:: item_formatter

:func:`linear_units`
--------------------

.. autofunction:: linear_units


:func:`make_iso_dict`
---------------------

.. autofunction:: make_iso_dict


:func:`make_log_abu_dict`
-------------------------

.. autofunction:: make_log_abu_dict


:func:`make_mf_dict`
---------------------

.. autofunction:: make_mf_dict


:func:`return_as_ndarray`
-------------------------

.. autofunction:: return_as_ndarray


:func:`return_string_as_list`
-----------------------------

.. autofunction:: return_string_as_list


:func:`return_list_simplifier`
-------------------------------

.. autofunction:: return_list_simplifier
